function Data_Argentina = Get_ArgentinaDataset(filename_prefix,species,mapping,wls)
% function to load Argentina dataset

Data_Argentina = [];

% Loop through each sheet
for species_N = 1:length(species)
    % Read the data from the selected sheet
    data = readtable([filename_prefix,species{species_N},'.csv']);
    data_cell = table2cell(data);
    
    % extract reflectance data
    data_idx = [];data_ref = [];
    cnt = 0;
    for col = 1:size(data_cell,2)
        if strcmp(class(data_cell{1,col}),'double') && ismember(data_cell{1, col}, wls)
            cnt = cnt + 1;
            for row = 2:size(data_cell,1)
                data_ref(row-1,cnt) = data_cell{row,col};
            end
            data_idx(1,cnt) = data_cell{1,col};
        end
    end
    
    idx_fileName = find(strcmp(data_cell(1,:),'File name'));
    idx_secondaryDomain = find(strcmp(data_cell(1,:),'Secondary domain'));
    
    if length(idx_fileName)>1
        idx_fileName = idx_fileName(1);
    end
    
    % Extract the "Secondary domain" column and "File name" column
    fileName = data{2:end,idx_fileName};

    % Update file names by removing numeric suffixes
    fileName = regexprep(fileName, '_(1|2|3)$', '');

    secondaryDomain = data{2:end,idx_secondaryDomain};
        
    fileName_unique = unique(fileName);
    secondaryDomain_unique = unique(secondaryDomain);
        
    % remove empty cell
    secondaryDomain_unique(cellfun('isempty', secondaryDomain_unique)) = [];
    
    % Average data across the same fileName (repetitions)
    data_ref_mean = zeros(length(fileName_unique),size(data_ref,2));
    data_secondaryDomain = {};
    data_reps = cell(length(fileName_unique),1);
    
    % Compute mean reflectance over measurement repetitions
    for ii = 1:length(fileName_unique)
        data_idx = find(strcmp(fileName,fileName_unique{ii}));

        data_reps{ii} = data_ref(data_idx,:);
        data_ref_mean(ii,:) = mean(data_ref(data_idx,:));
        
        %% check NaN        
        if sum(sum(isnan(data_ref_mean(ii,:))))
            disp(['NaN at',fileName_unique{ii}])
        end

        data_secondaryDomain{end + 1} = secondaryDomain{data_idx(1)};
    end
    
    for ii = 1:length(secondaryDomain_unique)
        data_idx = strcmp(secondaryDomain_unique{ii},data_secondaryDomain);
        Data_Argentina.(mapping(secondaryDomain_unique{ii})) = data_reps(data_idx,:);%data_ref_mean(data_idx,:);
    end
end

% Add wavelength range to data
Data_Argentina.wls = wls;
end