function plotAUC(data)
% Code to plot the are under the curve (AUC) of Argentina's natural objects reflectance.


%% AUC plots


switch data.category


    case 'barks'
        spectra = data.Argentina.barks;
        tname='Barks';
        CT = copper(size(spectra,1)/3);
        markerColor = [159 0 55]/255;

    case 'beetles'
        spectra = data.Argentina.beetles;
        tname='Beetles';
        CT = winter(size(spectra,1)/3);
        markerColor = [214 0 59]/255;

    case 'birds'
        spectra = data.Argentina.birds;
        tname='Birds';
        CT = autumn(round(size(spectra,1)/3));
        markerColor = [223 65 34]/255;

    case 'butterflies'
        spectra = data.Argentina.butterflies;
        tname='Butterflies';
        CT = parula(size(spectra,1)/3);
        markerColor = [228 135 41]/255;

    case 'flowers'
        spectra = data.Argentina.flowers;
        tname='Flowers';
        CT = spring(size(spectra,1));
        markerColor = [217 176 76]/255;
        
    case 'fruits'
        spectra = data.Argentina.fruits;
        tname='Fruits';
        CT = jet(round(size(spectra,1)/3));
        markerColor = [176 197 98]/255;

     case 'leaves'
        spectra = data.Argentina.leaves;
        tname='Leaves';
        CT = summer(size(spectra,1)/3);
        markerColor = [102 184 114]/255;

    case 'plantfruits'
        spectra = data.Argentina.plantfruits;
        tname='Plant fruits';
        CT = summer(size(spectra,1)/3);
        markerColor = [0 163 133]/255;

    case 'stones'
        spectra = data.Argentina.stones;
        tname='Stones';
        CT = lines(size(spectra,1)/3);
        markerColor = [0 108 164]/255;

    case 'vegetables'
        spectra = data.Argentina.vegetables;
        tname='Vegetables';
        CT = lines(size(spectra,1)/3);
        markerColor = [83 58 149]/255;
        
    case 'all'
        spectra =[data.Argentina.flowers; data.Argentina.leaves; data.Argentina.stones; data.Argentina.barks; data.Argentina.fruits; data.Argentina.vegetables; data.Argentina.plantfruits; data.Argentina.beetles; data.Argentina.butterflies; data.Argentina.birds];
        tname='All samples';
        CT = 'default';
        markerColor = [0.1 0.1 0.1];
    otherwise
        disp('incorrect name of category')
end


% Group
wls = data.Argentina.wls';
wl2 = 400:1000;
auc_s = nan(3,length(spectra));

for i = 1:length(spectra)
    indiv_specs = spectra{i};
    spec2=interp1(wls,indiv_specs',wl2);
    auci= sum(spec2);
    auci(end+1:3) = nan;
    auc_s(:,i)= auci;
end
 
m_s = nanmean(auc_s,2);
s_s = nanstd(auc_s,[],2);

if strcmp(data.category,'all')
    fsizes = [12, 16];
else
    fsizes = [20 ,28];
end

% figure of Comparison 3 measurements
figure,
set(gca,'colororder',CT);
hold on
plot(auc_s,'-*');
hold on
errorbar(m_s,s_s,'-o','Color',markerColor,'MarkerFaceColor',markerColor,'MarkerSize',6,'LineWidth',4)
ylabel('AUC (nm)','FontSize',14)
ylim([0 600])
xlim([0.5 3.5])
xticks([1 2 3])
xticklabels({'M1','M2','M3'})
ax=gca;
ax.FontSize = fsizes(1);
hold off
title(tname,'FontSize',fsizes(2))
set(gcf,'Position',[10 10 300 500])

filename = [tname,'_AUC' '.pdf'];
exportgraphics(gcf,fullfile('fig',filename),'ContentType','vector')
 
end

